const popupTypes = {
    exitIntent:'exitIntent',
    showAfterSeconds:'showAfterSeconds',
    showOnScroll:'showOnScroll',
    scrollToElement:'scrollToElement'

}

class DZMPopUpContainer{
    constructor(uid, type) {
        this.container = null
        this.uid = uid
        this.closeButton = null
        this.backdrop = null
        this.remember = false
        this.rememberDays = 0
        this.type = type
        this.showAfterSeconds = 0
        this.showOnScroll = 0
        this.scrollToElement = ""
        this.backdrop = document.createElement('div')
        this.backdrop.classList.add('modal-backdrop')
        this.backdrop.classList.add('fade')
        this.backdropContainer = null
        this.content = ""
        this.contentWrapper = null

        this.selectors = {
            containerSelector:'[data-dzm-popup-container="'+uid+'"]',
            closeButtonSelector: '[data-dzm-popup-closebutton="'+uid+'"]',
            backdropContainerSelector:'body',
            contentWrapperSelector:'.dzm-popup-content-wrapper'
        }

    }

    init(options){
        this.content = options.content
        this.remember = options.remember
        this.rememberDays = options.rememberDays
        console.log('hello from dzmPopupContainer',options)
        this.container = document.querySelector(this.selectors.containerSelector)
        this.closeButton = this.container.querySelector(this.selectors.closeButtonSelector)
        if(this.closeButton){
            this.closeButton.addEventListener('click',()=>{
                this.hide(this)
            })
        }

        this.backdropContainer = document.body

        if(this.container == null){
            console.warn('no popup found')
            return
        }
        this.contentWrapper = this.container.querySelector(this.selectors.contentWrapperSelector)

        if(this.getCookie(this.uid)===""){
            switch (this.type){
                case popupTypes.exitIntent:
                    document.addEventListener('mouseout', e=>{
                        if(!e.toElement && !e.relatedTarget){
                            this.show(this)
                        }
                    })
                    break;
                case popupTypes.scrollToElement:
                    if(!options.scrollToElement){
                        console.warn('scrollToElement Missing', options)
                        return;
                    }else{
                        this.scrollToElement = options.scrollToElement
                    }

                    let target = document.getElementById(this.scrollToElement);
                    if(target){
                        (new IntersectionObserver((entries, observer)=>{
                            entries.forEach(entry=>{
                                if(entry.isIntersecting){
                                    this.show(this)
                                    observer.unobserve(target)
                                }
                            })

                        },{root:null,rootMargin:'-50px', threshold:0.4})).observe(target)
                    }


                    break;
                case popupTypes.showAfterSeconds:
                    if(!options.showAfterSeconds){
                        console.warn('showAfterSeconds Missing', options)
                        return;
                    }else{
                        this.showAfterSeconds = options.showAfterSeconds
                    }
                    setTimeout(()=>{
                        this.show(this)
                    }, Math.abs(this.showAfterSeconds) * 1000 + 1)

                    break;
                case popupTypes.showOnScroll:
                    if(!options.showOnScroll){
                        console.warn('showOnScroll Missing', options)
                        return;
                    }else{
                        this.showOnScroll = options.showOnScroll
                    }
                    const handleScroll = ()=>{
                        console.log('scroll')
                        const windowHeight = window.innerHeight;
                        const fullDocumentHeight = document.documentElement.scrollHeight;
                        const scrolled = document.documentElement.scrollTop || document.body.scrollTop;

                        const scrollPercentage = (scrolled + windowHeight) / fullDocumentHeight * 100;

                        if (scrollPercentage >= this.showOnScroll) {
                            this.show(this);
                            // Optional: Event-Listener entfernen, damit 'show' nur einmal aufgerufen wird
                            document.removeEventListener('scroll', handleScroll);
                        }
                    }
                    document.addEventListener('scroll', handleScroll);
                    break;
                default:
                    break;


            }
        }else{
            console.log(' cookie for ',this.uid)
        }





    }

    /**
     *
     * @param {DZMPopUpContainer} instance
     */
    show(instance){
        this.contentWrapper.innerHTML = instance.content
        instance.backdropContainer.appendChild(instance.backdrop)
        setTimeout(()=>{
            instance.backdrop.classList.add('show')
            instance.backdrop.addEventListener('click',()=>{
                this.hide(instance)
            })
        },1)


        instance.container.classList.add('show')
    }

    hide(instance){
        instance.container.classList.remove('show')
        instance.backdrop.classList.remove('show')
        instance.backdrop.style.pointerEvents = 'none'
        setTimeout(()=>{
            instance.backdrop.remove()
            instance.backdrop.style.pointerEvents = 'all'
            this.contentWrapper.innerHTML = ''

        },500)

        console.log('hide', instance.remember)
        if(instance.remember){
            instance.setCookie(instance.uid,1,instance.rememberDays)
        }
    }

    getCookie(cname) {
        let name = cname + "=";
        let decodedCookie = decodeURIComponent(document.cookie);
        let ca = decodedCookie.split(';');
        for(let i = 0; i <ca.length; i++) {
            let c = ca[i];
            while (c.charAt(0) === ' ') {
                c = c.substring(1);
            }

            if (c.indexOf(name) === 0) {
                return c.substring(name.length, c.length);
            }
        }
        return "";
    }
    setCookie(cname, cvalue, exdays) {
        console.log('setCookie')
        const d = new Date();
        let expires = ''
        if(exdays > 0){
            d.setTime(d.getTime() + (exdays*24*60*60*1000));
            expires = "expires="+ d.toUTCString() + ';';
        }


        document.cookie = cname + "=" + cvalue + ";" + expires + "path=/";
    }
}