class DZMVideoPlayer{
    constructor(wrapper) {
        this.wrapper = wrapper;
        this.play = "";
        this.thumbnailContainer = "";
        this.videoContainer = "";
        this.video = "";
        this.selectors={
            play: "[data-dzm-vp-playbtn]",
            wrapper: "[data-dzm-vp-wrapper]",
            thumbnailContainer: "[data-dzm-vp-thumbnail-container]",
            videoContainer: "[data-dzm-vp-video-container]",
            video: "[data-dzm-vp-video]",
            closeButton: ".dzm-video-close",
        }
    }

    init(){
        this.play = this.wrapper.querySelector(this.selectors.play);
        this.thumbnailContainer = this.wrapper.querySelector(this.selectors.thumbnailContainer);
        this.videoContainer = this.wrapper.querySelector(this.selectors.videoContainer);
        this.video = this.wrapper.querySelector(this.selectors.video);
        this.closeButton = this.wrapper.querySelector(this.selectors.closeButton);

        this.play.addEventListener('click',()=>this.playClicked())

        this.closeButton.addEventListener("click", ()=>this.closeVideo())


        if (/Mobi/.test(navigator.userAgent)) {
            // The device is a mobile device
            this.wrapper.addEventListener("touchstart", (e) => {
                this.closeButton.style.display = '';
                setTimeout((e) => {
                    this.closeButton.style.display = 'none';
                }, 3000);
            })
        } else {
            // The device is a desktop device
            this.wrapper.addEventListener('mousemove', (e) => {
                this.fadeOut(e, this.closeButton)
            })
        }

    }

    playClicked(){
        console.log('playClicked')
        this.thumbnailContainer.classList.add('d-none');
        this.videoContainer.classList.remove('d-none');
        if(this.video != null){
            this.video.play();
        }
    }


    closeVideo(){
        this.thumbnailContainer.classList.remove('d-none');
        this.videoContainer.classList.add('d-none');
        this.video.pause();
    }

    fadeOut(e, closeButton){
        if (!this.fadeInBuffer) {
            if (this.timer) {
                clearTimeout(this.timer);
                this.timer = 0;
            }
            closeButton.style.display = '';
        } else {
            this.fadeInBuffer = false;
        }

        this.timer = setTimeout(function() {
            closeButton.style.display = 'none';
            this.fadeInBuffer = true;
        }, 3000);
    }
}

document.querySelectorAll("[data-dzm-vp-wrapper]").forEach(wrapper=>{
    let player = new DZMVideoPlayer(wrapper)
    player.init();
})
